@@ -1,17 +1,17 @@
 package CGI::Application::Plugin::RunmodeDeclare;
+our $VERSION = '0.07';
+
 
 use warnings;
 use strict;
 
-our $VERSION = '0.06';
-
 =head1 NAME
 
 CGI::Application::Plugin::RunmodeDeclare - Declare runmodes with keywords
 
 =head1 VERSION
 
-Version 0.06
+version 0.07
 
 =cut
 
@@ -150,7 +150,7 @@ sub inject_parsed_proto {
 
     for my $sig (@args) {
         my ($sigil, $name) = @$sig;
-        push @code, _default_for($sigil,$name,$invocant);
+        push @code, _default_for($sigil,$name,$invocant) if $sigil eq '$'; # CA->param only handles scalars
         push @code, _default_for($sigil,$name,"${invocant}->query");
     }
 
@@ -374,5 +374,4 @@ This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 
-=cut
-
+=cut
\ No newline at end of file
